@@ -4,7 +4,7 @@
 # Created on 2019/1/21
 from enum import Enum
 
-from api.model.MetaModel import MetaModel
+from api.model.MetaModel import MetaModel,MetaModelField
 
 
 class FactDatasource(object):
@@ -50,7 +50,7 @@ class FactDatasource(object):
         self.credentials = credentials
         self.target = target
         self.schema = schema
-        self.model: MetaModel = MetaModel(id=model) if model is not None else None
+        self.model = MetaModel(id=model) if isinstance(model, int) else model
         self.ttl = ttl
         self.tags = tags
         self.privilege = privilege
@@ -58,6 +58,15 @@ class FactDatasource(object):
 
         self._source_name = f'fd_{self.site}_{self.projectCode}_{self.code}'
 
+        #model是字典就转成对象，好多地方是model.x的方式取值的，字典这种取值不得行
+        if self.model is not None and isinstance(self.model, dict):
+            self.model = MetaModel(**self.model)
+            dict_fields = self.model.fields
+            if dict_fields is not None:
+                self.model.fields = []
+                for dict_field in dict_fields:
+                    self.model.fields.append(MetaModelField(**dict_field))
+
     def get_target_with_schema(self):
         if self.schema is None or len(self.schema) == 0:
             return self.target
@@ -93,6 +102,7 @@ class JdbcTypeEnum(Enum):
     MYSQL = 'MYSQL'
     ORACLE = 'ORACLE'
     VERNOX = 'VERNOX'
+    VERNOX_NTS = 'VERNOX_NTS'
     SQL_SERVER = 'SQL_SERVER'
     POSTGRESQL = 'POSTGRESQL'
     DB2 = 'DB2'
