@@ -20,6 +20,9 @@ def application_key():
 def secret_key():
     pass
 
+@Value("${sobeycube.oauth.oauth_uri}")
+def user_center_uri():
+    pass
 
 @Value("${sobeycube.oauth.username:}")
 def user_name():
@@ -46,7 +49,7 @@ def acquire_access_token():
     from client import AuthClient
 
     server, grant_type = ("sobeyficus", "client_credentials") if oauth2_type() == "server" else (
-        "SOBEY-USER-CENTER", "password")
+        user_center_uri(), "password")
 
     token, expiration = AuthClient.oauth_access_token(server, grant_type, application_key(), secret_key(), user_name(),
                                                       user_password())
