@@ -171,6 +171,10 @@ class FactDatasourceContextHolder(Singleton):
                 from factdatasource.persistence.jdbc.dialect.VernoxJdbcFactDatasourceContext import \
                     VernoxJdbcFactDatasourceContext
                 fd_context = VernoxJdbcFactDatasourceContext(fact_datasource)
+            elif jdbc_type == JdbcTypeEnum.VERNOX_NTS:
+                from factdatasource.persistence.jdbc.dialect.VernoxntsJdbcFactDatasourceContext import \
+                    VernoxntsJdbcFactDatasourceContext
+                fd_context = VernoxntsJdbcFactDatasourceContext(fact_datasource)
             else:
                 raise NotSupportedFDException(f'暂不支持该数据库{jdbc_type}')
         elif fd_type == FactDatasourceTypeEnum.AMQP:
